==> nextcloud-22.2.8.tgz: nextcloud/apps/weather_status/l10n/pt_BR.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Endereço desconhecido",
    "No result." : "Nenhum resultado.",
    "Malformed JSON data." : "Dados JSON mal formatados.",
    "Error" : "Erro",
    "Weather status" : "Status do Tempo",
    "Weather status in your dashboard" : "Status do Tempo no seu Painel",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Status do Tempo integrado no aplicativo Painel.\n    Localização do usuário pode ser obtida automaticamente ou definida manualmente. Uma previsão de 6 horas é então exibida.\n    Esse status também pode ser integrado em outros locais, como no aplicativo Calendário.",
    "Detect location" : "Detectar localização",
    "Set custom address" : "Definir endereço personalizado",
    "Favorites" : "Favoritos",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} céu claro mais tarde hoje",
    "{temperature} {unit} clear sky" : "{temperature} {unit} céu claro",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} nublado mais tarde hoje",
    "{temperature} {unit} cloudy" : "{temperature} {unit} nublado",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} tempo bom mais tarde hoje",
    "{temperature} {unit} fair weather" : "{temperature} {unit} tempo bom",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} parcialmente nublado hoje mais tarde",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} parcialmente nublado",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} nevoeiro mais tarde hoje",
    "{temperature} {unit} foggy" : "{temperature} {unit} nevoeiro",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} chuva fraca hoje mais tarde",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} chuva fraca hoje mais tarde",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} chuva fraca hoje mais tarde",
    "{temperature} {unit} rainfall" : "{temperatura} {unidade} precipitação",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} chuva forte mais tarde hoje",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} heavy rainfall",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} pancadas de chuva mais tarde hoje",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} pancadas de chuva",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} pancadas de chuva leves mais tarde hoje",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} chuvas leves",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} pancadas de chuva forte mais tarde hoje",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} chuvas fortes",
    "More weather for {adr}" : "Ver mais Tempo para {adr}",
    "Loading weather" : "Carregando Tempo",
    "Remove from favorites" : "Remover dos favoritos",
    "Add as favorite" : "Adicionar aos favoritos",
    "You are not logged in." : "Você não está conectado.",
    "There was an error getting the weather status information." : "Houve um erro na obtenção das informações de Tempo.",
    "No weather information found" : "Não encontradas informações de Tempo",
    "Location not found" : "Localização não encontrada",
    "There was an error setting the location address." : "Houve um erro ao definir o endereço.",
    "There was an error setting the location." : "Houve um erro ao definir a localização.",
    "There was an error saving the mode." : "Houve um erro ao salvar o modo.",
    "There was an error using personal address." : "Houve um erro ao usar o endereço pessoal.",
    "Set location for weather" : "Definir localização para o Tempo",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Céu limpo às {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Nublado às {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Dia ameno às {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Noite amena às {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Parcialmente nublado às {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Neblina às {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Garoa às {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Chuva às {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Chuva forte às {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Pancadas de chuva às {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Pancadas leves de chuva às {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Pancadas fortes de chuva às {time}"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-25.0.11.tgz: nextcloud/apps/weather_status/l10n/pt_BR.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Endereço desconhecido",
    "No result." : "Nenhum resultado.",
    "Malformed JSON data." : "Dados JSON mal formatados.",
    "Error" : "Erro",
    "Weather status" : "Status do Tempo",
    "Weather status in your dashboard" : "Status do Tempo no seu Painel",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Status do Tempo integrado no aplicativo Painel.\n    Localização do usuário pode ser obtida automaticamente ou definida manualmente. Uma previsão de 6 horas é então exibida.\n    Esse status também pode ser integrado em outros locais, como no aplicativo Calendário.",
    "Detect location" : "Detectar localização",
    "Set custom address" : "Definir endereço personalizado",
    "Favorites" : "Favoritos",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} céu claro mais tarde hoje",
    "{temperature} {unit} clear sky" : "{temperature} {unit} céu claro",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} nublado mais tarde hoje",
    "{temperature} {unit} cloudy" : "{temperature} {unit} nublado",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} tempo bom mais tarde hoje",
    "{temperature} {unit} fair weather" : "{temperature} {unit} tempo bom",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} parcialmente nublado hoje mais tarde",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} parcialmente nublado",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} nevoeiro mais tarde hoje",
    "{temperature} {unit} foggy" : "{temperature} {unit} nevoeiro",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} chuva fraca hoje mais tarde",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} chuva fraca hoje mais tarde",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} chuva fraca hoje mais tarde",
    "{temperature} {unit} rainfall" : "{temperatura} {unidade} precipitação",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} chuva forte mais tarde hoje",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} heavy rainfall",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} pancadas de chuva mais tarde hoje",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} pancadas de chuva",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} pancadas de chuva leves mais tarde hoje",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} chuvas leves",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} pancadas de chuva forte mais tarde hoje",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} chuvas fortes",
    "More weather for {adr}" : "Ver mais Tempo para {adr}",
    "Loading weather" : "Carregando Tempo",
    "Remove from favorites" : "Remover dos favoritos",
    "Add as favorite" : "Adicionar aos favoritos",
    "You are not logged in." : "Você não está conectado.",
    "There was an error getting the weather status information." : "Houve um erro na obtenção das informações de Tempo.",
    "No weather information found" : "Não encontradas informações de Tempo",
    "Location not found" : "Localização não encontrada",
    "There was an error setting the location address." : "Houve um erro ao definir o endereço.",
    "There was an error setting the location." : "Houve um erro ao definir a localização.",
    "There was an error saving the mode." : "Houve um erro ao salvar o modo.",
    "There was an error using personal address." : "Houve um erro ao usar o endereço pessoal.",
    "Set location for weather" : "Definir localização para o Tempo"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
